@@ -25,12 +25,14 @@ class BlockscoutClient:
         EthereumNetwork.ENERGY_WEB_CHAIN: "https://explorer.energyweb.org/",
         EthereumNetwork.VOLTA: "https://volta-explorer.energyweb.org/",
         EthereumNetwork.OLYMPUS: "https://explorer.polis.tech",
+        EthereumNetwork.BOBA_NETWORK_BOBABEAM: "https://blockexplorer.bobabeam.boba.network/",
         EthereumNetwork.BOBA_RINKEBY: "https://blockexplorer.rinkeby.boba.network/",
         EthereumNetwork.BOBA: "https://blockexplorer.boba.network/",
         EthereumNetwork.GATHER_DEVNET: "https://devnet-explorer.gather.network/",
         EthereumNetwork.GATHER_TESTNET: "https://testnet-explorer.gather.network/",
         EthereumNetwork.GATHER_MAINNET: "https://explorer.gather.network/",
         EthereumNetwork.METIS_TESTNET: "https://stardust-explorer.metis.io/",
+        EthereumNetwork.METIS_GOERLI_TESTNET: "https://goerli.explorer.metisdevops.link/",
         EthereumNetwork.METIS: "https://andromeda-explorer.metis.io/",
         EthereumNetwork.FUSE_MAINNET: "https://explorer.fuse.io/",
         EthereumNetwork.VELAS_MAINNET: "https://evmexplorer.velas.com/",
@@ -50,6 +52,12 @@ class BlockscoutClient:
         EthereumNetwork.ASTAR: "https://blockscout.com/astar/",
         EthereumNetwork.EVMOS_MAINNET: "https://evm.evmos.org",
         EthereumNetwork.EVMOS_TESTNET: "https://evm.evmos.dev",
+        EthereumNetwork.RABBIT: "https://rabbit.analogscan.com",
+        EthereumNetwork.KCC_MAINNET: "https://scan.kcc.io/",
+        EthereumNetwork.KCC_TESTNET: "https://scan-testnet.kcc.network/",
+        EthereumNetwork.ARBITRUM: "https://explorer.arbitrum.io",
+        EthereumNetwork.ARBITRUM_NOVA: "https://nova-explorer.arbitrum.io",
+        EthereumNetwork.ARBITRUM_GOERLI: "https://goerli-rollup-explorer.arbitrum.io",
     }
 
     def __init__(self, network: EthereumNetwork):
