@@ -40,6 +40,7 @@ class EtherscanClient:
         EthereumNetwork.MOON_MOONBASE: "https://moonbase.moonscan.io",
         EthereumNetwork.CRONOS_MAINNET: "https://cronoscan.com",
         EthereumNetwork.CRONOS_TESTNET: "https://testnet.cronoscan.com",
+        EthereumNetwork.CELO: "https://celoscan.io",
     }
 
     NETWORK_WITH_API_URL = {
@@ -47,7 +48,7 @@ class EtherscanClient:
         EthereumNetwork.RINKEBY: "https://api-rinkeby.etherscan.io",
         EthereumNetwork.ROPSTEN: "https://api-ropsten.etherscan.io",
         EthereumNetwork.GOERLI: "https://api-goerli.etherscan.io/",
-        EthereumNetwork.KOVAN: "https://api-kovan.etherscan.io/",
+        EthereumNetwork.KOVAN: "https://api-kovan.etherscan.io",
         EthereumNetwork.BINANCE: "https://api.bscscan.com",
         EthereumNetwork.MATIC: "https://api.polygonscan.com",
         EthereumNetwork.OPTIMISTIC: "https://api-optimistic.etherscan.io",
@@ -60,6 +61,7 @@ class EtherscanClient:
         EthereumNetwork.MOON_MOONBASE: "https://api-moonbase.moonscan.io",
         EthereumNetwork.CRONOS_MAINNET: "https://api.cronoscan.com",
         EthereumNetwork.CRONOS_TESTNET: "https://api-testnet.cronoscan.com",
+        EthereumNetwork.CELO: "https://api.celoscan.io",
     }
     HTTP_HEADERS = {
         "User-Agent": "curl/7.77.0",
