@@ -100,6 +100,7 @@ class EthereumNetwork(Enum):
     TAO_CORE = 558
     METIS_TESTNET = 588
     MACA_TESTNET = 595
+    METIS_GOERLI_TESTNET = 599
     KAR = 686
     FETH_FACTORY127_TESTNET = 721
     CHEAPETH_CHEAPNET = 777
@@ -126,8 +127,11 @@ class EthereumNetwork(Enum):
     MOON_MOONSHADOW = 1288
     GANACHE = 1337
     CATECHAIN = 1618
+    RABBIT = 1807
     EURUS_TESTNET = 1984
     EGEM = 1987
+    PUBLICMINT_TESTNET = 2019
+    PUBLICMINT_MAINNET = 2020
     EDG = 2021
     EDG_BERESHEET = 2022
     KORTHO = 2559
@@ -176,6 +180,7 @@ class EthereumNetwork(Enum):
     SPARTA_TESTNET = 333888
     OLYMPUS = 333999
     ARBITRUM_TESTNET = 421611
+    ARBITRUM_GOERLI = 421613
     ETHO = 1313114
     XERO = 1313500
     MUSIC = 7762959
@@ -308,7 +313,7 @@ class EthereumNetwork(Enum):
     FREIGHT_TRUST_NETWORK = 211
     PERMISSION = 222
     SUR_BLOCKCHAIN_NETWORK = 262
-    KCC_MAINET = 321
+    KCC_MAINNET = 321
     CALLISTO_MAINNET = 820
     WORLD_TRADE_TECHNICAL_BLOCKCHAIN = 1202
     ATHEIOS = 1620
@@ -329,7 +334,9 @@ class EthereumNetwork(Enum):
     EVANESCO_TESTNET = 1201
     SINGULARITY_ZERO_TESTNET = 12051
     OYCHAIN_TESTNET = 125
+    BOBA_NETWORK_BOBABEAM = 1294
     BOBA_NETWORK_BOBABASE = 1297
+    BOBA_AVAX_L2 = 43288
     ETND_CHAIN_MAINNETS = 131419
     AITD_MAINNET = 1319
     AITD_TESTNET = 1320
@@ -354,6 +361,7 @@ class EthereumNetwork(Enum):
     HARADEV_TESTNET = 197710212031
     MILKOMEDA_C1_MAINNET = 2001
     MILKOMEDA_C1_TESTNET = 200101
+    MILKOMEDA_A1_MAINNET = 2002
     MILKOMEDA_A1_TESTNET = 200202
     CLOUDWALK_MAINNET = 2009
     CLOUDWALK_TESTNET = 2008
